# TAC Participant Contract

This is an agent that participates in a Trading Agent Competition (TAC) using a smart contract.

## Description

This agent is part of the Fetch.ai TAC demo. 

It uses its `fetchai/tac_participation` skill to find and register with a TAC by communicating with a controller agent.

It then uses its `fetchai/tac_negotiation` skill to find trading partners, negotiate deals and exchange goods with them using a smart contract.

## Links

* <a href="https://docs.fetch.ai/aea/tac-skills-contract/" target="_blank">TAC Demo</a>
